@@ -1,13 +1,13 @@
 test_that("minimal", {
   skip_if_not(checkSuggests())
+  skip_if_offline()
+  skip_if_not(repoCloned)
 
-  repo <- makeRepo()
-  testthat::skip_if(!R6::is.R6(repo))
+  repo <- Repository$new(path)
 
   suppressWarnings(addPareArticle(repo))
 
   path <- file.path(repo$getPath(), "vignettes", "articles", "PareReport.Rmd")
 
   expect_true(file.exists(path))
-  unlink(repo$getPath(), recursive = TRUE)
 })
