@@ -1,6 +1,3 @@
-library(PaRe)
-library(testthat)
-
 # if dlply calls > 0
 #   lapply
 #     if dlply call %in% defined functions
@@ -10,8 +7,11 @@ library(testthat)
 # 2: if1 if2
 
 test_that("minimal", {
-  repo <- makeRepo()
-  testthat::skip_if_not(all(class(repo) == c("Repository", "R6")))
+  skip_if_offline()
+  skip_if_not(repoCloned)
+
+  repo <- Repository$new(path)
+
   files <- repo$getRFiles()
   glueIdx <- sapply(files, function(file) {
     file$getName() == "glue.R"
@@ -28,5 +28,4 @@ test_that("minimal", {
   fun <- funs[glueIdx][[1]]
 
   expect_null(PaRe:::getDlplyCall(fun, defFuns))
-  unlink(repo$getPath(), recursive = TRUE)
 })
