@@ -1,9 +1,9 @@
-library(PaRe)
-library(testthat)
-
 test_that("minimal", {
-  repo <- makeRepo()
-  testthat::skip_if_not(all(class(repo) == c("Repository", "R6")))
+  skip_if_offline()
+  skip_if_not(repoCloned)
+
+  repo <- Repository$new(path)
+
   files <- repo$getRFiles()
   glueIdx <- sapply(files, function(file) {
     file$getName() == "glue.R"
@@ -20,5 +20,4 @@ test_that("minimal", {
   fun <- funs[glueIdx][[1]]
 
   expect_null(PaRe:::getDoCall(fun, defFuns))
-  unlink(repo$getPath(), recursive = TRUE)
 })
